@@ -1010,9 +1010,9 @@ long cm_Lookup(cm_scache_t *dscp, char *namep, long flags, cm_user_t *userp,
                 return CM_ERROR_NOSUCHFILE;
         }
         else {  /* nonexistent dir on freelance root, so add it */
-			osi_Log1(afsd_logp,"cm_Lookup adding mount for non-existent directory: %s", namep);
-            code = cm_FreelanceAddMount(namep, namep, "root.cell.",
-					&rock.fid);
+			osi_Log1(afsd_logp,"cm_Lookup adding mount for non-existent directory: %s", 
+                     osi_LogSaveString(afsd_logp,namep));
+			code = cm_FreelanceAddMount(namep, namep, "root.cell.", namep[0] == '.', &rock.fid);
             if (code < 0) {   /* add mount point failed, so give up */
                 if (flags & CM_FLAG_CHECKPATH)
                     return CM_ERROR_NOSUCHPATH;
@@ -1114,8 +1114,7 @@ long cm_Unlink(cm_scache_t *dscp, char *namep, cm_user_t *userp, cm_req_t *reqp)
                 code = RXAFS_RemoveFile(connp->callp, &afsFid, namep,
 					&newDirStatus, &volSync);
 		
-	} while (cm_Analyze(connp, userp, reqp,
-			    &dscp->fid, &volSync, NULL, code));
+	} while (cm_Analyze(connp, userp, reqp, &dscp->fid, &volSync, NULL, NULL, code));
         code = cm_MapRPCError(code, reqp);
 
         lock_ObtainMutex(&dscp->mx);
@@ -1275,6 +1274,9 @@ long cm_NameI(cm_scache_t *rootSCachep, char *pathp, long flags,
         	tp = pathp;
 		phase = 2;
 	}
+	if (tp == NULL) {
+		tp = "";
+	}
 	haveComponent = 0;
         psp = NULL;
         tscp = rootSCachep;
@@ -1548,9 +1550,10 @@ long cm_TryBulkProc(cm_scache_t *scp, cm_dirEntry_t *dep, void *rockp,
 	// yj: if this is a mountpoint under root.afs then we don't want it
 	// to be bulkstat-ed, instead, we call getSCache directly and under
 	// getSCache, it is handled specially.
-	if 	(cm_freelanceEnabled &&
-           tfid.cell==0x1 && tfid.volume==AFS_FAKE_ROOT_VOL_ID &&
-			   !(tfid.vnode==0x1 && tfid.unique==0x1) )
+	if 	( cm_freelanceEnabled &&
+          tfid.cell==AFS_FAKE_ROOT_CELL_ID && 
+          tfid.volume==AFS_FAKE_ROOT_VOL_ID &&
+          !(tfid.vnode==0x1 && tfid.unique==0x1) )
 	{
         osi_Log0(afsd_logp, "cm_TryBulkProc Freelance calls cm_SCache on root.afs mountpoint");
 		return cm_GetSCache(&tfid, &tscp, NULL, NULL);
@@ -1626,7 +1629,7 @@ void cm_TryBulkStat(cm_scache_t *dscp, osi_hyper_t *offsetp, cm_user_t *userp,
                         	&statStruct, &callbackStruct, &volSync);
 
 		} while (cm_Analyze(connp, userp, reqp, &dscp->fid,
-				    &volSync, &cbReq, code));
+				    &volSync, NULL, &cbReq, code));
                 code = cm_MapRPCError(code, reqp);
 
                 osi_Log0(afsd_logp, "CALL BulkStatus DONE");
@@ -1846,7 +1849,7 @@ long cm_SetAttr(cm_scache_t *scp, cm_attr_t *attrp, cm_user_t *userp,
 			&afsInStatus, &afsOutStatus, &volSync);
 
 	} while (cm_Analyze(connp, userp, reqp,
-			    &scp->fid, &volSync, NULL, code));
+			    &scp->fid, &volSync, NULL, NULL, code));
         code = cm_MapRPCError(code, reqp);
 
 	osi_Log1(afsd_logp, "CALL StoreStatus DONE, code %d", code);
@@ -1919,7 +1922,7 @@ long cm_Create(cm_scache_t *dscp, char *namep, long flags, cm_attr_t *attrp,
 					&updatedDirStatus, &newFileCallback,
 					&volSync);
 	} while (cm_Analyze(connp, userp, reqp,
-			    &dscp->fid, &volSync, &cbReq, code));
+			    &dscp->fid, &volSync, NULL, &cbReq, code));
         code = cm_MapRPCError(code, reqp);
         
         lock_ObtainMutex(&dscp->mx);
@@ -2035,7 +2038,7 @@ long cm_MakeDir(cm_scache_t *dscp, char *namep, long flags, cm_attr_t *attrp,
 				     &updatedDirStatus, &newDirCallback,
 				     &volSync);
 	} while (cm_Analyze(connp, userp, reqp,
-			    &dscp->fid, &volSync, &cbReq, code));
+			    &dscp->fid, &volSync, NULL, &cbReq, code));
         code = cm_MapRPCError(code, reqp);
         
         lock_ObtainMutex(&dscp->mx);
@@ -2117,7 +2120,7 @@ long cm_SymLink(cm_scache_t *dscp, char *namep, char *contentsp, long flags,
 				     &inStatus, &newAFSFid, &newLinkStatus,
 				     &updatedDirStatus, &volSync);
 	} while (cm_Analyze(connp, userp, reqp,
-			    &dscp->fid, &volSync, NULL, code));
+			    &dscp->fid, &volSync, NULL, NULL, code));
         code = cm_MapRPCError(code, reqp);
         
         lock_ObtainMutex(&dscp->mx);
@@ -2186,7 +2189,7 @@ long cm_RemoveDir(cm_scache_t *dscp, char *namep, cm_user_t *userp,
                 code = RXAFS_RemoveDir(connp->callp, &dirAFSFid, namep,
 					&updatedDirStatus, &volSync);
 	} while (cm_Analyze(connp, userp, reqp,
-			    &dscp->fid, &volSync, NULL, code));
+			    &dscp->fid, &volSync, NULL, NULL, code));
         code = cm_MapRPCErrorRmdir(code, reqp);
         
         lock_ObtainMutex(&dscp->mx);
@@ -2326,7 +2329,7 @@ long cm_Rename(cm_scache_t *oldDscp, char *oldNamep, cm_scache_t *newDscp,
 			&updatedOldDirStatus, &updatedNewDirStatus,
                 	&volSync);
 	} while (cm_Analyze(connp, userp, reqp, &oldDscp->fid,
-			    &volSync, NULL, code));
+			    &volSync, NULL, NULL, code));
         code = cm_MapRPCError(code, reqp);
         
 	/* update the individual stat cache entries for the directories */
@@ -2398,7 +2401,7 @@ long cm_Lock(cm_scache_t *scp, unsigned char LockType,
 			code = RXAFS_SetLock(connp->callp, &tfid, Which,
 					     &volSync);
 		} while (cm_Analyze(connp, userp, reqp, &scp->fid, &volSync,
-				    NULL, code));
+				    NULL, NULL, code));
 		lock_ObtainMutex(&scp->mx);
 		code = cm_MapRPCError(code, reqp);
 	}
@@ -2489,7 +2492,7 @@ long cm_Unlock(cm_scache_t *scp, unsigned char LockType,
                 break;
 			code = RXAFS_ReleaseLock(connp->callp, &tfid, &volSync);
 		} while (cm_Analyze(connp, userp, reqp, &scp->fid, &volSync,
-				    NULL, code));
+				    NULL, NULL, code));
 		code = cm_MapRPCError(code, reqp);
 		lock_ObtainMutex(&scp->mx);
 	}
@@ -2530,7 +2533,7 @@ void cm_CheckLocks()
 				code = RXAFS_ExtendLock(connp->callp, &tfid,
 							&volSync);
 			} while (cm_Analyze(connp, fileLock->userp, &req,
-					    &fileLock->fid, &volSync, NULL,
+					    &fileLock->fid, &volSync, NULL, NULL,
 					    code));
 			code = cm_MapRPCError(code, &req);
 			lock_ObtainWrite(&cm_scacheLock);
@@ -2598,7 +2601,7 @@ long cm_RetryLock(cm_file_lock_t *oldFileLock, int vcp_is_dead)
 					     &volSync);
 		} while (cm_Analyze(connp, oldFileLock->userp, &req,
 				    &oldFileLock->fid, &volSync,
-				    NULL, code));
+				    NULL, NULL, code));
 		code = cm_MapRPCError(code, &req);
 	}
 
