@@ -46,8 +46,8 @@
 #define SYS_NAME_ID_hp_ux102	 	 414
 #define SYS_NAME_ID_hp_ux110	 	 415
 #define SYS_NAME_ID_hp_ux11i             416
-#define SYS_NAME_ID_ia64_hpux1122		 417
-#define SYS_NAME_ID_ia64_hpux1123		 418
+#define SYS_NAME_ID_ia64_hpux1122	 417
+#define SYS_NAME_ID_ia64_hpux1123	 418
 
 #define SYS_NAME_ID_mac2_51		 500
 #define SYS_NAME_ID_mac_aux10		 501
@@ -92,11 +92,14 @@
 #define SYS_NAME_ID_sun4x_57		 938
 #define SYS_NAME_ID_sun4x_58		 939
 #define SYS_NAME_ID_sun4x_59		 940
+#define SYS_NAME_ID_sun4x_510		 941
 
 /* Sigh. If I leave a gap here IBM will do this sequentially. If I don't
    they won't allocate sunx86 IDs at all. So leave a gap and pray. */
-#define SYS_NAME_ID_sunx86_57            950
-#define SYS_NAME_ID_sunx86_58            951
+#define SYS_NAME_ID_sunx86_57		 950
+#define SYS_NAME_ID_sunx86_58		 951
+#define SYS_NAME_ID_sunx86_59		 952
+#define SYS_NAME_ID_sunx86_510		 953
 
 #define SYS_NAME_ID_vax_ul4		1003
 #define SYS_NAME_ID_vax_ul40		1004
@@ -130,6 +133,7 @@
 #define SYS_NAME_ID_i386_linux2		1500
 #define SYS_NAME_ID_i386_linux22	1501
 #define SYS_NAME_ID_i386_linux24        1502
+#define SYS_NAME_ID_i386_linux26        1503
 
 #define SYS_NAME_ID_ppc_linux2          1600
 #define SYS_NAME_ID_ppc_linux22         1601
@@ -160,6 +164,7 @@
 #define SYS_NAME_ID_i386_fbsd_50        2105
 #define SYS_NAME_ID_i386_fbsd_51        2106
 #define SYS_NAME_ID_i386_fbsd_52        2107
+#define SYS_NAME_ID_i386_fbsd_53        2108
 
 #define SYS_NAME_ID_ia64_linux2		2200
 #define SYS_NAME_ID_ia64_linux22	2201
@@ -193,6 +198,7 @@
 #define SYS_NAME_ID_i386_obsd33		2602
 #define SYS_NAME_ID_i386_obsd34		2603
 #define SYS_NAME_ID_i386_obsd35		2604
+#define SYS_NAME_ID_i386_obsd36		2605
 
 #define SYS_NAME_ID_amd64_linux2        2700
 #define SYS_NAME_ID_amd64_linux22       2701
